@@ -28,6 +28,7 @@
 
 #include "config.h"
 
+#include <locale.h>
 #include <stdlib.h>
 
 #include <gdesktop-enums.h>
@@ -2117,6 +2118,19 @@ photos_application_startup (GApplication *application)
 }
 
 
+static void
+photos_application_constructed (GObject *object)
+{
+  PhotosApplication *self = PHOTOS_APPLICATION (object);
+  const gchar *app_id;
+
+  G_OBJECT_CLASS (photos_application_parent_class)->constructed (object);
+
+  app_id = g_application_get_application_id (G_APPLICATION (self));
+  g_set_prgname (app_id);
+}
+
+
 static void
 photos_application_dispose (GObject *object)
 {
@@ -2220,6 +2234,14 @@ photos_application_finalize (GObject *object)
 static void
 photos_application_init (PhotosApplication *self)
 {
+  setlocale (LC_ALL, "");
+
+  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
+
+  g_set_application_name (_("Photos"));
+
   photos_utils_ensure_builtins ();
 
   self->state = photos_search_context_state_new (PHOTOS_SEARCH_CONTEXT (self));
@@ -2236,6 +2258,7 @@ photos_application_class_init (PhotosApplicationClass *class)
   GObjectClass *object_class = G_OBJECT_CLASS (class);
   GApplicationClass *application_class = G_APPLICATION_CLASS (class);
 
+  object_class->constructed = photos_application_constructed;
   object_class->dispose = photos_application_dispose;
   object_class->finalize = photos_application_finalize;
   application_class->activate = photos_application_activate;
