@@ -102,6 +102,9 @@ photos_glib_file_create_data_free (PhotosGLibFileCreateData *data)
 }
 
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (PhotosGLibFileCreateData, photos_glib_file_create_data_free);
+
+
 static gchar *
 photos_glib_file_create_data_get_filename (PhotosGLibFileCreateData *data)
 {
@@ -120,7 +123,7 @@ static PhotosGLibFileCreateData *
 photos_glib_file_create_data_new (GFile *file, GFileCreateFlags flags, gint io_priority)
 {
   PhotosGLibFileCreateData *data;
-  gchar *filename;
+  g_autofree gchar *filename = NULL;
 
   data = g_slice_new0 (PhotosGLibFileCreateData);
 
@@ -132,8 +135,6 @@ photos_glib_file_create_data_new (GFile *file, GFileCreateFlags flags, gint io_p
   data->flags = flags;
   data->io_priority = io_priority;
 
-  g_free (filename);
-
   return data;
 }
 
@@ -142,54 +143,55 @@ static void
 photos_glib_file_create_create (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
   GCancellable *cancellable;
-  GError *error = NULL;
   GFile *file = G_FILE (source_object);
-  GFile *unique_file = NULL;
-  GFileOutputStream *stream = NULL;
-  GTask *task = G_TASK (user_data);
+  g_autoptr (GFileOutputStream) stream = NULL;
+  g_autoptr (GTask) task = G_TASK (user_data);
   PhotosGLibFileCreateData *data;
-  gchar *filename = NULL;
 
   cancellable = g_task_get_cancellable (task);
   data = (PhotosGLibFileCreateData *) g_task_get_task_data (task);
 
-  stream = g_file_create_finish (file, res, &error);
-  if (error != NULL)
-    {
-      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-        {
-          g_task_return_error (task, error);
-          goto out;
-        }
+  {
+    g_autoptr (GError) error = NULL;
 
-      if (data->count == G_MAXUINT)
-        {
-          g_task_return_new_error (task, PHOTOS_ERROR, 0, "Exceeded number of copies of a file");
-          goto out;
-        }
+    stream = g_file_create_finish (file, res, &error);
+    if (error != NULL)
+      {
+        g_autoptr (GFile) unique_file = NULL;
+        g_autofree gchar *filename = NULL;
 
-      data->count++;
+        if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
+          {
+            g_task_return_error (task, g_steal_pointer (&error));
+            goto out;
+          }
 
-      filename = photos_glib_file_create_data_get_filename (data);
-      unique_file = g_file_get_child (data->dir, filename);
+        if (data->count == G_MAXUINT)
+          {
+            g_task_return_new_error (task, PHOTOS_ERROR, 0, "Exceeded number of copies of a file");
+            goto out;
+          }
 
-      g_file_create_async (unique_file,
-                           data->flags,
-                           data->io_priority,
-                           cancellable,
-                           photos_glib_file_create_create,
-                           g_object_ref (task));
+        data->count++;
 
-      goto out;
-    }
+        filename = photos_glib_file_create_data_get_filename (data);
+        unique_file = g_file_get_child (data->dir, filename);
+
+        g_file_create_async (unique_file,
+                             data->flags,
+                             data->io_priority,
+                             cancellable,
+                             photos_glib_file_create_create,
+                             g_object_ref (task));
+
+        goto out;
+      }
+  }
 
   g_task_return_pointer (task, g_object_ref (stream), g_object_unref);
 
  out:
-  g_free (filename);
-  g_clear_object (&stream);
-  g_clear_object (&unique_file);
-  g_object_unref (task);
+  return;
 }
 
 
@@ -201,23 +203,16 @@ photos_glib_file_create_async (GFile *file,
                                GAsyncReadyCallback callback,
                                gpointer user_data)
 {
-  GTask *task;
-  PhotosGLibFileCreateData *data;
+  g_autoptr (GTask) task = NULL;
+  g_autoptr (PhotosGLibFileCreateData) data = NULL;
 
   task = g_task_new (file, cancellable, callback, user_data);
   g_task_set_source_tag (task, photos_glib_file_create_async);
 
   data = photos_glib_file_create_data_new (file, flags, io_priority);
-  g_task_set_task_data (task, data, (GDestroyNotify) photos_glib_file_create_data_free);
+  g_task_set_task_data (task, g_steal_pointer (&data), (GDestroyNotify) photos_glib_file_create_data_free);
 
-  g_file_create_async (file,
-                       data->flags,
-                       data->io_priority,
-                       cancellable,
-                       photos_glib_file_create_create,
-                       g_object_ref (task));
-
-  g_object_unref (task);
+  g_file_create_async (file, flags, io_priority, cancellable, photos_glib_file_create_create, g_object_ref (task));
 }
 
 
@@ -242,12 +237,11 @@ photos_glib_file_create_finish (GFile *file, GAsyncResult *res, GFile **out_uniq
   if (out_unique_file != NULL)
     {
       GFile *unique_file;
-      gchar *filename = NULL;
+      g_autofree gchar *filename = NULL;
 
       filename = photos_glib_file_create_data_get_filename (data);
       unique_file = g_file_get_child (data->dir, filename);
       *out_unique_file = unique_file;
-      g_free (filename);
     }
 
  out:
