@@ -99,7 +99,7 @@ photos_header_bar_new (void)
 void
 photos_header_bar_clear (PhotosHeaderBar *self)
 {
-  GList *children;
+  g_autoptr (GList) children = NULL;
   GList *l;
 
   self->mode = PHOTOS_HEADER_BAR_MODE_NONE;
@@ -108,8 +108,6 @@ photos_header_bar_clear (PhotosHeaderBar *self)
   children = gtk_container_get_children (GTK_CONTAINER (self));
   for (l = children; l != NULL; l = l->next)
     gtk_widget_destroy (GTK_WIDGET (l->data));
-
-  g_list_free (children);
 }
 
 
