@@ -55,7 +55,10 @@ photos_operation_insta_filter_setup (PhotosOperationInstaFilter *self)
 {
   GeglOperation *operation = GEGL_OPERATION (self);
   GeglNode *node;
-  GList *l;
+
+  g_return_if_fail (GEGL_IS_NODE (operation->node));
+  g_return_if_fail (GEGL_IS_NODE (self->input));
+  g_return_if_fail (GEGL_IS_NODE (self->output));
 
   g_list_free_full (self->nodes, g_object_unref);
   self->nodes = NULL;
@@ -63,10 +66,6 @@ photos_operation_insta_filter_setup (PhotosOperationInstaFilter *self)
   switch (self->preset)
     {
     case PHOTOS_OPERATION_INSTA_PRESET_NONE:
-      node = gegl_node_new_child (operation->node,
-                                  "operation", "gegl:nop",
-                                  NULL);
-      self->nodes = g_list_prepend (self->nodes, node);
       break;
 
     case PHOTOS_OPERATION_INSTA_PRESET_1977:
@@ -117,21 +116,30 @@ photos_operation_insta_filter_setup (PhotosOperationInstaFilter *self)
       break;
     }
 
-  node = GEGL_NODE (self->nodes->data);
-  gegl_node_link (self->input, node);
-
-  for (l = self->nodes; l != NULL && l->next != NULL; l = l->next)
+  if (self->nodes == NULL)
     {
-      GeglNode *sink = GEGL_NODE (l->next->data);
-      GeglNode *source = GEGL_NODE (l->data);
-
-      gegl_node_link (source, sink);
-      gegl_operation_meta_watch_node (operation, source);
+      gegl_node_link (self->input, self->output);
     }
+  else
+    {
+      GList *l;
 
-  node = GEGL_NODE (l->data);
-  gegl_node_link (node, self->output);
-  gegl_operation_meta_watch_node (operation, node);
+      node = GEGL_NODE (self->nodes->data);
+      gegl_node_link (self->input, node);
+
+      for (l = self->nodes; l != NULL && l->next != NULL; l = l->next)
+        {
+          GeglNode *sink = GEGL_NODE (l->next->data);
+          GeglNode *source = GEGL_NODE (l->data);
+
+          gegl_node_link (source, sink);
+          gegl_operation_meta_watch_node (operation, source);
+        }
+
+      node = GEGL_NODE (l->data);
+      gegl_node_link (node, self->output);
+      gegl_operation_meta_watch_node (operation, node);
+    }
 }
 
 
@@ -142,7 +150,7 @@ photos_operation_insta_filter_set_preset (PhotosOperationInstaFilter *self, Phot
     return;
 
   self->preset = preset;
-  if (self->input != NULL)
+  if (GEGL_OPERATION (self)->node != NULL)
     photos_operation_insta_filter_setup (self);
 }
 
