@@ -62,22 +62,24 @@ photos_pixbuf_new_from_file_at_size_in_thread_func (GTask *task,
                                                     gpointer task_data,
                                                     GCancellable *cancellable)
 {
-  GError *error;
-  GdkPixbuf *result = NULL;
+  g_autoptr (GdkPixbuf) result = NULL;
   PhotosPixbufNewFromFileData *data = (PhotosPixbufNewFromFileData *) task_data;
 
-  error = NULL;
-  result = gdk_pixbuf_new_from_file_at_size (data->filename, data->width, data->height, &error);
-  if (error != NULL)
-    {
-      g_task_return_error (task, error);
-      goto out;
-    }
+  {
+    g_autoptr (GError) error = NULL;
+
+    result = gdk_pixbuf_new_from_file_at_size (data->filename, data->width, data->height, &error);
+    if (error != NULL)
+      {
+        g_task_return_error (task, g_steal_pointer (&error));
+        goto out;
+      }
+  }
 
   g_task_return_pointer (task, g_object_ref (result), g_object_unref);
 
  out:
-  g_clear_object (&result);
+  return;
 }
 
 
@@ -89,7 +91,7 @@ photos_pixbuf_new_from_file_at_size_async (const gchar *filename,
                                            GAsyncReadyCallback callback,
                                            gpointer user_data)
 {
-  GTask *task;
+  g_autoptr (GTask) task = NULL;
   PhotosPixbufNewFromFileData *data;
 
   g_return_if_fail (filename != NULL && filename[0] != '\0');
@@ -103,7 +105,6 @@ photos_pixbuf_new_from_file_at_size_async (const gchar *filename,
   g_task_set_task_data (task, data, (GDestroyNotify) photos_pixbuf_new_from_file_data_free);
 
   g_task_run_in_thread (task, photos_pixbuf_new_from_file_at_size_in_thread_func);
-  g_object_unref (task);
 }
 
 
