@@ -115,6 +115,8 @@ photos_tracker_change_event_get_urn_id (PhotosTrackerChangeEvent *self)
 void
 photos_tracker_change_event_merge (PhotosTrackerChangeEvent *self, PhotosTrackerChangeEvent *event)
 {
+  g_return_if_fail (g_strcmp0 (self->urn, event->urn) == 0);
+
   if (event->type == PHOTOS_TRACKER_CHANGE_EVENT_DELETED || event->type == PHOTOS_TRACKER_CHANGE_EVENT_CREATED)
     self->type = event->type;
 }
@@ -125,6 +127,9 @@ photos_tracker_change_event_set_resolved_values (PhotosTrackerChangeEvent *self,
                                                  const gchar *urn,
                                                  const gchar *predicate)
 {
+  g_return_if_fail (self->predicate == NULL);
+  g_return_if_fail (self->urn == NULL);
+
   self->urn = g_strdup (urn);
   self->predicate = g_strdup (predicate);
 
