@@ -115,16 +115,20 @@ photos_utils_center_pixbuf (GdkPixbuf *pixbuf, gint size)
 gchar *
 photos_utils_convert_path_to_uri (const gchar *path)
 {
-  GFile *file;
-  gchar *uri;
+  g_autoptr (GFile) file = NULL;
+  gchar *uri = NULL;
 
   if (path == NULL)
-    return g_strdup ("");
+    {
+      uri = g_strdup ("");
+      goto out;
+    }
 
   file = g_file_new_for_path (path);
   uri = g_file_get_uri (file);
-  g_object_unref (file);
 
+ out:
+  g_return_val_if_fail (uri != NULL, NULL);
   return uri;
 }
 
@@ -132,13 +136,13 @@ photos_utils_convert_path_to_uri (const gchar *path)
 GIcon *
 photos_utils_create_collection_icon (gint base_size, GList *pixbufs)
 {
-  cairo_surface_t *surface;
-  cairo_t *cr;
+  cairo_surface_t *surface; /* TODO: use g_autoptr */
+  cairo_t *cr; /* TODO: use g_autoptr */
   GdkPixbuf *pix;
   GIcon *ret_val;
   GList *l;
-  GtkStyleContext *context;
-  GtkWidgetPath *path;
+  g_autoptr (GtkStyleContext) context = NULL;
+  g_autoptr (GtkWidgetPath) path = NULL;
   gint cur_x;
   gint cur_y;
   gint padding;
@@ -172,7 +176,6 @@ photos_utils_create_collection_icon (gint base_size, GList *pixbufs)
   path = gtk_widget_path_new ();
   gtk_widget_path_append_type (path, GTK_TYPE_ICON_VIEW);
   gtk_style_context_set_path (context, path);
-  gtk_widget_path_unref (path);
 
   surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, base_size, base_size);
   cr = cairo_create (surface);
@@ -224,7 +227,6 @@ photos_utils_create_collection_icon (gint base_size, GList *pixbufs)
 
   cairo_surface_destroy (surface);
   cairo_destroy (cr);
-  g_object_unref (context);
 
   return ret_val;
 }
@@ -234,13 +236,12 @@ GdkPixbuf *
 photos_utils_create_placeholder_icon_for_scale (const gchar *name, gint size, gint scale)
 {
   GApplication *app;
-  GdkPixbuf *centered_pixbuf = NULL;
-  GdkPixbuf *pixbuf = NULL;
+  g_autoptr (GdkPixbuf) centered_pixbuf = NULL;
+  g_autoptr (GdkPixbuf) pixbuf = NULL;
   GdkPixbuf *ret_val = NULL;
-  GError *error;
-  GIcon *icon = NULL;
+  g_autoptr (GIcon) icon = NULL;
   GList *windows;
-  GtkIconInfo *info = NULL;
+  g_autoptr (GtkIconInfo) info = NULL;
   GtkIconTheme *theme;
   GtkStyleContext *context;
   gint size_scaled;
@@ -262,14 +263,16 @@ photos_utils_create_placeholder_icon_for_scale (const gchar *name, gint size, gi
 
   context = gtk_widget_get_style_context (GTK_WIDGET (windows->data));
 
-  error = NULL;
-  pixbuf = gtk_icon_info_load_symbolic_for_context (info, context, NULL, &error);
-  if (error != NULL)
-    {
-      g_warning ("Unable to load icon '%s': %s", name, error->message);
-      g_error_free (error);
-      goto out;
-    }
+  {
+    g_autoptr (GError) error = NULL;
+
+    pixbuf = gtk_icon_info_load_symbolic_for_context (info, context, NULL, &error);
+    if (error != NULL)
+      {
+        g_warning ("Unable to load icon '%s': %s", name, error->message);
+        goto out;
+      }
+  }
 
   size_scaled = size * scale;
   centered_pixbuf = photos_utils_center_pixbuf (pixbuf, size_scaled);
@@ -278,10 +281,6 @@ photos_utils_create_placeholder_icon_for_scale (const gchar *name, gint size, gi
   centered_pixbuf = NULL;
 
  out:
-  g_clear_object (&centered_pixbuf);
-  g_clear_object (&pixbuf);
-  g_clear_object (&info);
-  g_clear_object (&icon);
   return ret_val;
 }
 
@@ -289,17 +288,17 @@ photos_utils_create_placeholder_icon_for_scale (const gchar *name, gint size, gi
 GIcon *
 photos_utils_create_symbolic_icon_for_scale (const gchar *name, gint base_size, gint scale)
 {
-  GIcon *icon;
+  g_autoptr (GIcon) icon = NULL;
   GIcon *ret_val = NULL;
-  GdkPixbuf *pixbuf;
-  GtkIconInfo *info;
+  g_autoptr (GdkPixbuf) pixbuf = NULL;
+  g_autoptr (GtkIconInfo) info = NULL;
   GtkIconTheme *theme;
-  GtkStyleContext *style;
-  GtkWidgetPath *path;
-  cairo_surface_t *icon_surface = NULL;
-  cairo_surface_t *surface;
-  cairo_t *cr;
-  gchar *symbolic_name;
+  g_autoptr (GtkStyleContext) style = NULL;
+  g_autoptr (GtkWidgetPath) path = NULL;
+  cairo_surface_t *icon_surface = NULL; /* TODO: use g_autoptr */
+  cairo_surface_t *surface; /* TODO: use g_autoptr */
+  cairo_t *cr; /* TODO: use g_autoptr */
+  g_autofree gchar *symbolic_name = NULL;
   const gint bg_size = 24;
   const gint emblem_margin = 4;
   gint emblem_pos;
@@ -320,7 +319,6 @@ photos_utils_create_symbolic_icon_for_scale (const gchar *name, gint base_size,
   path = gtk_widget_path_new ();
   gtk_widget_path_append_type (path, GTK_TYPE_ICON_VIEW);
   gtk_style_context_set_path (style, path);
-  gtk_widget_path_unref (path);
 
   gtk_style_context_add_class (style, "photos-icon-bg");
 
@@ -328,23 +326,17 @@ photos_utils_create_symbolic_icon_for_scale (const gchar *name, gint base_size,
 
   symbolic_name = g_strconcat (name, "-symbolic", NULL);
   icon = g_themed_icon_new_with_default_fallbacks (symbolic_name);
-  g_free (symbolic_name);
 
   theme = gtk_icon_theme_get_default();
   info = gtk_icon_theme_lookup_by_gicon_for_scale (theme, icon, emblem_size, scale, GTK_ICON_LOOKUP_FORCE_SIZE);
-  g_object_unref (icon);
-
   if (info == NULL)
     goto out;
 
   pixbuf = gtk_icon_info_load_symbolic_for_context (info, style, NULL, NULL);
-  g_object_unref (info);
-
   if (pixbuf == NULL)
     goto out;
 
   icon_surface = gdk_cairo_surface_create_from_pixbuf (pixbuf, scale, NULL);
-  g_object_unref (pixbuf);
 
   emblem_pos = total_size - emblem_size - emblem_margin;
   gtk_render_icon_surface (style, cr, icon_surface, emblem_pos, emblem_pos);
@@ -352,7 +344,6 @@ photos_utils_create_symbolic_icon_for_scale (const gchar *name, gint base_size,
   ret_val = G_ICON (gdk_pixbuf_get_from_surface (surface, 0, 0, total_size_scaled, total_size_scaled));
 
  out:
-  g_object_unref (style);
   cairo_surface_destroy (icon_surface);
   cairo_surface_destroy (surface);
   cairo_destroy (cr);
@@ -372,7 +363,7 @@ photos_utils_create_thumbnail (GFile *file,
                                GCancellable *cancellable,
                                GError **error)
 {
-  PhotosThumbnailFactory *factory = NULL;
+  g_autoptr (PhotosThumbnailFactory) factory = NULL;
   gboolean ret_val = FALSE;
 
   factory = photos_thumbnail_factory_dup_singleton (NULL, NULL);
@@ -390,7 +381,6 @@ photos_utils_create_thumbnail (GFile *file,
   ret_val = TRUE;
 
  out:
-  g_clear_object (&factory);
   return ret_val;
 }
 
@@ -398,19 +388,17 @@ photos_utils_create_thumbnail (GFile *file,
 GVariant *
 photos_utils_create_zoom_target_value (gdouble delta, PhotosZoomEvent event)
 {
-  GEnumClass *zoom_event_class = NULL;
+  GEnumClass *zoom_event_class = NULL; /* TODO: use g_autoptr */
   GEnumValue *event_value;
   GVariant *delta_value;
   GVariant *event_nick_value;
   GVariant *ret_val = NULL;
-  GVariantBuilder builder;
+  g_auto (GVariantBuilder) builder = G_VARIANT_BUILDER_INIT (G_VARIANT_TYPE_VARDICT);
   const gchar *event_nick = "none";
 
   g_return_val_if_fail (delta >= 0.0, NULL);
   g_return_val_if_fail (event != PHOTOS_ZOOM_EVENT_NONE, NULL);
 
-  g_variant_builder_init (&builder, G_VARIANT_TYPE_VARDICT);
-
   delta_value = g_variant_new_double (delta);
   g_variant_builder_add (&builder, "{sv}", "delta", delta_value);
 
@@ -434,27 +422,28 @@ photos_utils_create_zoom_target_value (gdouble delta, PhotosZoomEvent event)
 static GIcon *
 photos_utils_get_thumbnail_icon (const gchar *uri)
 {
-  GError *error;
-  GFile *file = NULL;
-  GFile *thumb_file = NULL;
-  GFileInfo *info = NULL;
+  g_autoptr (GFile) file = NULL;
+  g_autoptr (GFile) thumb_file = NULL;
+  g_autoptr (GFileInfo) info = NULL;
   GIcon *icon = NULL;
   const gchar *thumb_path;
 
   file = g_file_new_for_uri (uri);
 
-  error = NULL;
-  info = photos_utils_file_query_info (file,
-                                       G_FILE_ATTRIBUTE_THUMBNAIL_PATH,
-                                       G_FILE_QUERY_INFO_NONE,
-                                       NULL,
-                                       &error);
-  if (error != NULL)
-    {
-      g_warning ("Unable to fetch thumbnail path for %s: %s", uri, error->message);
-      g_error_free (error);
-      goto out;
-    }
+  {
+    g_autoptr (GError) error = NULL;
+
+    info = photos_utils_file_query_info (file,
+                                         G_FILE_ATTRIBUTE_THUMBNAIL_PATH,
+                                         G_FILE_QUERY_INFO_NONE,
+                                         NULL,
+                                         &error);
+    if (error != NULL)
+      {
+        g_warning ("Unable to fetch thumbnail path for %s: %s", uri, error->message);
+        goto out;
+      }
+  }
 
   thumb_path = g_file_info_get_attribute_byte_string (info, G_FILE_ATTRIBUTE_THUMBNAIL_PATH);
   if (thumb_path == NULL)
@@ -464,9 +453,6 @@ photos_utils_get_thumbnail_icon (const gchar *uri)
   icon = g_file_icon_new (thumb_file);
 
  out:
-  g_clear_object (&thumb_file);
-  g_clear_object (&info);
-  g_clear_object (&file);
   return icon;
 }
 
@@ -809,13 +795,13 @@ photos_utils_file_copy_as_thumbnail (GFile *source,
                                      GCancellable *cancellable,
                                      GError **error)
 {
-  GFileInputStream *istream = NULL;
-  GFileOutputStream *ostream = NULL;
-  GdkPixbuf *pixbuf = NULL;
+  g_autoptr (GFileInputStream) istream = NULL;
+  g_autoptr (GFileOutputStream) ostream = NULL;
+  g_autoptr (GdkPixbuf) pixbuf = NULL;
   gboolean ret_val = FALSE;
   const gchar *prgname;
-  gchar *original_height_str = NULL;
-  gchar *original_width_str = NULL;
+  g_autofree gchar *original_height_str = NULL;
+  g_autofree gchar *original_width_str = NULL;
 
   g_return_val_if_fail (G_IS_FILE (source), FALSE);
   g_return_val_if_fail (G_IS_FILE (destination), FALSE);
@@ -860,11 +846,6 @@ photos_utils_file_copy_as_thumbnail (GFile *source,
   ret_val = TRUE;
 
  out:
-  g_free (original_height_str);
-  g_free (original_width_str);
-  g_clear_object (&istream);
-  g_clear_object (&ostream);
-  g_clear_object (&pixbuf);
   return ret_val;
 }
 
@@ -876,8 +857,8 @@ photos_utils_file_query_info (GFile *file,
                               GCancellable *cancellable,
                               GError **error)
 {
-  GFileAttributeMatcher *matcher = NULL;
-  GFileInfo *info = NULL;
+  GFileAttributeMatcher *matcher = NULL; /* TODO: use g_autoptr */
+  g_autoptr (GFileInfo) info = NULL;
   GFileInfo *ret_val = NULL;
 
   g_return_val_if_fail (G_IS_FILE (file), NULL);
@@ -894,7 +875,7 @@ photos_utils_file_query_info (GFile *file,
       || g_file_attribute_matcher_matches (matcher, G_FILE_ATTRIBUTE_THUMBNAIL_PATH)
       || g_file_attribute_matcher_matches (matcher, G_FILE_ATTRIBUTE_THUMBNAILING_FAILED))
     {
-      gchar *path = NULL;
+      g_autofree gchar *path = NULL;
 
       g_file_info_remove_attribute (info, G_FILE_ATTRIBUTE_THUMBNAIL_IS_VALID);
       g_file_info_remove_attribute (info, G_FILE_ATTRIBUTE_THUMBNAIL_PATH);
@@ -907,14 +888,11 @@ photos_utils_file_query_info (GFile *file,
           g_file_info_set_attribute_byte_string (info, G_FILE_ATTRIBUTE_THUMBNAIL_PATH, path);
           g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_THUMBNAILING_FAILED, FALSE);
         }
-
-      g_free (path);
     }
 
   ret_val = g_object_ref (info);
 
  out:
-  g_clear_object (&info);
   g_clear_pointer (&matcher, (GDestroyNotify) g_file_attribute_matcher_unref);
   return ret_val;
 }
@@ -949,7 +927,7 @@ photos_utils_file_query_info_in_thread_func (GTask *task,
 {
   GError *error;
   GFile *file = G_FILE (source_object);
-  GFileInfo *info = NULL;
+  g_autoptr (GFileInfo) info = NULL;
   PhotosUtilsFileQueryInfoData *data = (PhotosUtilsFileQueryInfoData *) task_data;
 
   error = NULL;
@@ -963,7 +941,7 @@ photos_utils_file_query_info_in_thread_func (GTask *task,
   g_task_return_pointer (task, g_object_ref (info), g_object_unref);
 
  out:
-  g_clear_object (&info);
+  return;
 }
 
 
@@ -976,7 +954,7 @@ photos_utils_file_query_info_async (GFile *file,
                                     GAsyncReadyCallback callback,
                                     gpointer user_data)
 {
-  GTask *task;
+  g_autoptr (GTask) task = NULL;
   PhotosUtilsFileQueryInfoData *data;
   const gchar *wildcard;
 
@@ -995,7 +973,6 @@ photos_utils_file_query_info_async (GFile *file,
   g_task_set_task_data (task, data, (GDestroyNotify) photos_utils_file_query_info_data_free);
 
   g_task_run_in_thread (task, photos_utils_file_query_info_in_thread_func);
-  g_object_unref (task);
 }
 
 
@@ -1017,8 +994,8 @@ photos_utils_get_controller (PhotosWindowMode mode,
                              PhotosOffsetController **out_offset_cntrlr,
                              PhotosTrackerController **out_trk_cntrlr)
 {
-  PhotosOffsetController *offset_cntrlr = NULL;
-  PhotosTrackerController *trk_cntrlr = NULL;
+  g_autoptr (PhotosOffsetController) offset_cntrlr = NULL;
+  g_autoptr (PhotosTrackerController) trk_cntrlr = NULL;
 
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_NONE);
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_EDIT);
@@ -1064,16 +1041,13 @@ photos_utils_get_controller (PhotosWindowMode mode,
 
   if (out_trk_cntrlr != NULL)
     g_set_object (out_trk_cntrlr, trk_cntrlr);
-
-  g_clear_object (&offset_cntrlr);
-  g_clear_object (&trk_cntrlr);
 }
 
 
 gchar *
 photos_utils_get_extension_from_mime_type (const gchar *mime_type)
 {
-  GSList *formats;
+  g_autoptr (GSList) formats = NULL;
   GSList *l;
   gchar *ret_val = NULL;
 
@@ -1082,7 +1056,7 @@ photos_utils_get_extension_from_mime_type (const gchar *mime_type)
   for (l = formats; l != NULL; l = l->next)
     {
       GdkPixbufFormat *format = (GdkPixbufFormat*) l->data;
-      gchar **supported_mime_types;
+      g_auto (GStrv) supported_mime_types = NULL;
       guint i;
 
       supported_mime_types = gdk_pixbuf_format_get_mime_types (format);
@@ -1095,12 +1069,10 @@ photos_utils_get_extension_from_mime_type (const gchar *mime_type)
             }
         }
 
-      g_strfreev (supported_mime_types);
       if (ret_val != NULL)
         break;
     }
 
-  g_slist_free (formats);
   return ret_val;
 }
 
@@ -1129,7 +1101,7 @@ photos_utils_get_icon_size_unscaled (void)
 gchar *
 photos_utils_get_pixbuf_common_suffix (GdkPixbufFormat *format)
 {
-  gchar **extensions;
+  g_auto (GStrv) extensions = NULL;
   gchar *result = NULL;
   gint i;
 
@@ -1154,8 +1126,6 @@ photos_utils_get_pixbuf_common_suffix (GdkPixbufFormat *format)
   if (result == NULL)
     result = g_ascii_strdown (extensions[0], -1);
 
-  g_strfreev (extensions);
-
   return result;
 }
 
@@ -1179,7 +1149,7 @@ photos_utils_get_selection_mode (void)
 {
   GAction *action;
   GApplication *app;
-  GVariant *state;
+  g_autoptr (GVariant) state = NULL;
   gboolean selection_mode;
 
   app = g_application_get_default ();
@@ -1190,7 +1160,6 @@ photos_utils_get_selection_mode (void)
 
   selection_mode = g_variant_get_boolean (state);
 
-  g_variant_unref (state);
   return selection_mode;
 }
 
@@ -1199,12 +1168,11 @@ gchar *
 photos_utils_get_thumbnail_path_for_file (GFile *file)
 {
   gchar *path;
-  gchar *uri = NULL;
+  g_autofree gchar *uri = NULL;
 
   uri = g_file_get_uri (file);
   path = photos_utils_get_thumbnail_path_for_uri (uri);
 
-  g_free (uri);
   return path;
 }
 
@@ -1213,10 +1181,10 @@ gchar *
 photos_utils_get_thumbnail_path_for_uri (const gchar *uri)
 {
   const gchar *cache_dir;
-  gchar *filename = NULL;
-  gchar *md5 = NULL;
+  g_autofree gchar *filename = NULL;
+  g_autofree gchar *md5 = NULL;
   gchar *path;
-  gchar *thumbnails_subdir = NULL;
+  g_autofree gchar *thumbnails_subdir = NULL;
   gint size;
 
   md5 = g_compute_checksum_for_string (G_CHECKSUM_MD5, uri, -1);
@@ -1233,9 +1201,6 @@ photos_utils_get_thumbnail_path_for_uri (const gchar *uri)
                            filename,
                            NULL);
 
-  g_free (filename);
-  g_free (md5);
-  g_free (thumbnails_subdir);
   return path;
 }
 
@@ -1319,7 +1284,7 @@ photos_utils_object_list_free_full (GList *objects)
 gchar *
 photos_utils_print_zoom_action_detailed_name (const gchar *action_name, gdouble delta, PhotosZoomEvent event)
 {
-  GVariant *target_value;
+  g_autoptr (GVariant) target_value = NULL;
   gchar *ret_val = NULL;
 
   g_return_val_if_fail (action_name != NULL && action_name[0] != '\0', NULL);
@@ -1331,7 +1296,6 @@ photos_utils_print_zoom_action_detailed_name (const gchar *action_name, gdouble
 
   ret_val = g_action_print_detailed_name (action_name, target_value);
 
-  g_variant_unref (target_value);
   return ret_val;
 }
 
@@ -1410,75 +1374,72 @@ photos_utils_update_executed (GObject *source_object, GAsyncResult *res, gpointe
 {
   TrackerSparqlConnection *connection = TRACKER_SPARQL_CONNECTION (source_object);
   const gchar *urn = (gchar *) user_data;
-  GError *error;
 
-  error = NULL;
-  tracker_sparql_connection_update_finish (connection, res, &error);
-  if (error != NULL)
-    {
+  {
+    g_autoptr (GError) error = NULL;
+
+    tracker_sparql_connection_update_finish (connection, res, &error);
+    if (error != NULL)
       g_warning ("Unable to update %s: %s", urn, error->message);
-      g_error_free (error);
-    }
+  }
 }
 
 
 void
 photos_utils_set_edited_name (const gchar *urn, const gchar *title)
 {
-  GError *error;
-  PhotosQuery *query = NULL;
-  PhotosTrackerQueue *queue = NULL;
-  gchar *sparql = NULL;
+  g_autoptr (PhotosQuery) query = NULL;
+  g_autoptr (PhotosTrackerQueue) queue = NULL;
+  g_autofree gchar *sparql = NULL;
 
   sparql = g_strdup_printf ("INSERT OR REPLACE { <%s> nie:title \"%s\" }", urn, title);
   query = photos_query_new (NULL, sparql);
 
-  error = NULL;
-  queue = photos_tracker_queue_dup_singleton (NULL, &error);
-  if (G_UNLIKELY (error != NULL))
-    {
-      g_warning ("Unable to set edited name %s: %s", urn, error->message);
-      g_error_free (error);
-      goto out;
-    }
+  {
+    g_autoptr (GError) error = NULL;
+
+    queue = photos_tracker_queue_dup_singleton (NULL, &error);
+    if (G_UNLIKELY (error != NULL))
+      {
+        g_warning ("Unable to set edited name %s: %s", urn, error->message);
+        goto out;
+      }
+  }
 
   photos_tracker_queue_update (queue, query, NULL, photos_utils_update_executed, g_strdup (urn), g_free);
 
  out:
-  g_clear_object (&query);
-  g_clear_object (&queue);
-  g_free (sparql);
+  return;
 }
 
 
 void
 photos_utils_set_favorite (const gchar *urn, gboolean is_favorite)
 {
-  GError *error;
-  PhotosQuery *query = NULL;
-  PhotosTrackerQueue *queue = NULL;
-  gchar *sparql = NULL;
+  g_autoptr (PhotosQuery) query = NULL;
+  g_autoptr (PhotosTrackerQueue) queue = NULL;
+  g_autofree gchar *sparql = NULL;
 
   sparql = g_strdup_printf ("%s { <%s> nao:hasTag nao:predefined-tag-favorite }",
                             (is_favorite) ? "INSERT OR REPLACE" : "DELETE",
                             urn);
   query = photos_query_new (NULL, sparql);
 
-  error = NULL;
-  queue = photos_tracker_queue_dup_singleton (NULL, &error);
-  if (G_UNLIKELY (error != NULL))
-    {
-      g_warning ("Unable to set favorite %s: %s", urn, error->message);
-      g_error_free (error);
-      goto out;
-    }
+  {
+    g_autoptr (GError) error = NULL;
+
+    queue = photos_tracker_queue_dup_singleton (NULL, &error);
+    if (G_UNLIKELY (error != NULL))
+      {
+        g_warning ("Unable to set favorite %s: %s", urn, error->message);
+        goto out;
+      }
+  }
 
   photos_tracker_queue_update (queue, query, NULL, photos_utils_update_executed, g_strdup (urn), g_free);
 
  out:
-  g_free (sparql);
-  g_clear_object (&query);
-  g_clear_object (&queue);
+  return;
 }
 
 
