@@ -52,6 +52,15 @@ G_BEGIN_DECLS
   "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#image-category-screenshot"
 #define PHOTOS_EXPORT_SUBPATH "Exports"
 
+typedef enum
+{
+  PHOTOS_ZOOM_EVENT_NONE,
+  PHOTOS_ZOOM_EVENT_KEYBOARD_ACCELERATOR,
+  PHOTOS_ZOOM_EVENT_MOUSE_CLICK,
+  PHOTOS_ZOOM_EVENT_SCROLL,
+  PHOTOS_ZOOM_EVENT_TOUCH
+} PhotosZoomEvent;
+
 GdkPixbuf       *photos_utils_center_pixbuf               (GdkPixbuf *pixbuf, gint size);
 
 gchar           *photos_utils_convert_path_to_uri         (const gchar *path);
@@ -72,8 +81,14 @@ gboolean         photos_utils_create_thumbnail            (GFile *file,
                                                            GCancellable *cancellable,
                                                            GError **error);
 
+GVariant        *photos_utils_create_zoom_target_value    (gdouble delta, PhotosZoomEvent event);
+
 GIcon           *photos_utils_get_icon_from_cursor        (TrackerSparqlCursor *cursor);
 
+gdouble          photos_utils_get_zoom_delta              (GVariant *dictionary);
+
+PhotosZoomEvent  photos_utils_get_zoom_event              (GVariant *dictionary);
+
 GdkPixbuf       *photos_utils_downscale_pixbuf_for_scale  (GdkPixbuf *pixbuf, gint size, gint scale);
 
 void             photos_utils_draw_rectangle_handles      (cairo_t *cr,
@@ -159,6 +174,10 @@ void             photos_utils_list_box_header_func        (GtkListBoxRow *row,
 
 void             photos_utils_object_list_free_full       (GList *objects);
 
+gchar           *photos_utils_print_zoom_action_detailed_name (const gchar *action_name,
+                                                               gdouble delta,
+                                                               PhotosZoomEvent event);
+
 gboolean         photos_utils_scrolled_window_can_scroll  (GtkScrolledWindow *scrolled_window);
 
 void             photos_utils_scrolled_window_scroll      (GtkScrolledWindow *scrolled_window,
