@@ -78,8 +78,6 @@ photos_zoom_controls_update_buttons (PhotosZoomControls *self)
       GVariant *target_value = NULL;
 
       target_value = photos_utils_create_zoom_target_value (1.0, PHOTOS_ZOOM_EVENT_MOUSE_CLICK);
-      g_assert_true (g_variant_is_floating (target_value));
-
       gtk_actionable_set_action_target_value (GTK_ACTIONABLE (self->zoom_toggle_button), target_value);
       gtk_actionable_set_action_name (GTK_ACTIONABLE (self->zoom_toggle_button), "app.zoom-in");
     }
@@ -151,8 +149,8 @@ static void
 photos_zoom_controls_realize (GtkWidget *widget)
 {
   GdkVisual *visual;
+  g_autoptr (GdkWindow) window = NULL;
   GdkWindow *parent_window;
-  GdkWindow *window;
   GdkWindowAttr attributes;
   GtkAllocation allocation;
   gint attributes_mask;
@@ -184,8 +182,6 @@ photos_zoom_controls_realize (GtkWidget *widget)
   window = gdk_window_new (parent_window, &attributes, attributes_mask);
   gtk_widget_set_window (widget, g_object_ref (window));
   gtk_widget_register_window (widget, window);
-
-  g_object_unref (window);
 }
 
 
